@@ -6,155 +6,120 @@ use warnings;
 use Carp;
 use Search::Tools::RegExp;
 
-use base qw( Class::Accessor::Fast );
+use base qw( Search::Tools::Object );
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
-sub new
-{
-    my $proto = shift;
-    my $class = ref($proto) || $proto;
-    my $self  = {};
-    bless($self, $class);
-    $self->_init(@_);
-    return $self;
-}
+__PACKAGE__->mk_accessors(
+    qw(
+        query
+        rekw
+        tag
+        class
+        colors
+        tty
+        ttycolors
+        no_html
+        ),
+    @Search::Tools::Accessors
+);
 
-sub _init
-{
-    my $self  = shift;
-    my %extra = @_;
-    @$self{keys %extra} = values %extra;
+sub _init {
+    my $self = shift;
+    $self->SUPER::_init(@_);
 
-    $self->mk_accessors(
-        qw(
-          query
-          rekw
-          tag
-          class
-          colors
-          tty
-          ttycolors
-          no_html
-          ),
-        @Search::Tools::Accessors
-    );
-
-    $self->{debug} ||= $ENV{PERL_DEBUG} || 0;
-
-    if ($self->debug)
-    {
+    if ( $self->debug ) {
         carp "debug level set at " . $self->debug;
     }
 
-    if (!$self->query)
-    {
+    if ( !$self->query ) {
         croak "query required.";
     }
-    elsif (ref $self->query eq 'ARRAY' or !ref $self->query)
-    {
-        my $re =
-          Search::Tools::RegExp->new(map { $_ => $self->$_ }
-                                     @Search::Tools::Accessors);
-        $self->rekw($re->build($self->query));
+    elsif ( ref $self->query eq 'ARRAY' or !ref $self->query ) {
+        my $re = Search::Tools::RegExp->new( map { $_ => $self->$_ }
+                @Search::Tools::Accessors );
+        $self->rekw( $re->build( $self->query ) );
     }
-    elsif ($self->query->isa('Search::Tools::RegExp::Keywords'))
-    {
-        $self->rekw($self->query);
+    elsif ( $self->query->isa('Search::Tools::RegExp::Keywords') ) {
+        $self->rekw( $self->query );
     }
-    else
-    {
+    else {
         croak
-          "query must be either a string or Search::Tools::RegExp::Keywords object";
+            "query must be either a string or Search::Tools::RegExp::Keywords object";
     }
 
-    unless ($self->rekw)
-    {
+    unless ( $self->rekw ) {
         croak "Search:Tools::RegExp::Keywords object required";
     }
 
     $self->{tag} ||= 'span';
-    $self->{colors} ||= ['#ffff99', '#99ffff', '#ffccff', '#ccccff'];
-    $self->{ttycolors} ||= ['bold blue', 'bold red', 'bold green'];
+    $self->{colors} ||= [ '#ffff99', '#99ffff', '#ffccff', '#ccccff' ];
+    $self->{ttycolors} ||= [ 'bold blue', 'bold red', 'bold green' ];
 
-    if ($self->tty)
-    {
+    if ( $self->tty ) {
         eval { require Term::ANSIColor };
         $self->tty(0) if $@;
     }
 
     $self->_build_tags;
-
-    #carp Dumper $self;
-
 }
 
-sub keywords
-{
+sub keywords {
     my $self = shift;
     return $self->rekw->keywords;
 }
 
-sub _phrases
-{
+sub _phrases {
     my $self = shift;
     return grep { $self->rekw->re($_)->phrase } $self->keywords;
 }
 
-sub _singles
-{
+sub _singles {
     my $self = shift;
     return grep { !$self->rekw->re($_)->phrase } $self->keywords;
 }
 
-sub _kworder
-{
+sub _kworder {
     my $self = shift;
 
     # do phrases first so that duplicates privilege phrases
-    $self->{_kworder} ||= [$self->_phrases, $self->_singles];
-    return @{$self->{_kworder}};
+    $self->{_kworder} ||= [ $self->_phrases, $self->_singles ];
+    return @{ $self->{_kworder} };
 }
 
-sub _build_tags
-{
+sub _build_tags {
     my $self = shift;
 
     my $t         = {};
-    my @colors    = @{$self->colors};
-    my @ttycolors = @{$self->ttycolors};
+    my @colors    = @{ $self->colors };
+    my @ttycolors = @{ $self->ttycolors };
     my $tag       = $self->tag;
 
     my $n = 0;
     my $m = 0;
 
-    for my $q ($self->_kworder)
-    {
+    for my $q ( $self->_kworder ) {
 
         # if tty flag is on, use ansicolor instead of html
         # if debug flag is on, use both html and ansicolor
 
-        my (%tags, $hO);
+        my ( %tags, $hO );
         $tags{open}  = '';
         $tags{close} = '';
-        if ($self->class)
-        {
+        if ( $self->class ) {
             $hO = qq/<$tag class="/ . $self->class . qq/">/;
         }
-        else
-        {
+        else {
             $hO = qq/<$tag style="background:/ . $colors[$n] . qq/">/;
         }
 
-        if ($self->tty)
-        {
+        if ( $self->tty ) {
             $tags{open} .= $hO if $self->debug && !$self->no_html;
-            $tags{open}  .= Term::ANSIColor::color($ttycolors[$m]);
+            $tags{open}  .= Term::ANSIColor::color( $ttycolors[$m] );
             $tags{close} .= Term::ANSIColor::color('reset');
             $tags{close} .= "</$tag>" if $self->debug && !$self->no_html;
         }
-        else
-        {
+        else {
             $tags{open}  .= $hO;
             $tags{close} .= "</$tag>";
         }
@@ -168,37 +133,31 @@ sub _build_tags
     $self->{_tags} = $t;
 }
 
-sub open_tag
-{
+sub open_tag {
     my $self = shift;
     my $q = shift or croak "need query to get open_tag";
     return $self->{_tags}->{$q}->{open} || '';
 }
 
-sub close_tag
-{
+sub close_tag {
     my $self = shift;
     my $q = shift or croak "need query to get close_tag";
     return $self->{_tags}->{$q}->{close} || '';
 }
 
-sub light
-{
+sub light {
     my $self = shift;
     my $text = shift or return '';
 
-    if (Search::Tools::RegExp->isHTML($text) && !$self->no_html)
-    {
+    if ( Search::Tools::RegExp->isHTML($text) && !$self->no_html ) {
         return $self->html($text);
     }
-    else
-    {
+    else {
         return $self->plain($text);
     }
 }
 
-sub _get_real_html
-{
+sub _get_real_html {
     my $self = shift;
     my $text = shift;
     my $re   = shift;
@@ -206,11 +165,9 @@ sub _get_real_html
 
     # $1 should be st_bound, $2 should be query, $3 should be end_bound
 
-    while ($$text =~ m/$re/g)
-    {
+    while ( $$text =~ m/$re/g ) {
 
-        if ($self->debug > 1)
-        {
+        if ( $self->debug > 1 ) {
             carp "$2 matches $re";
         }
 
@@ -226,8 +183,7 @@ sub _get_real_html
 }
 
 # based on HTML::HiLiter hilite()
-sub html
-{
+sub html {
     my $self = shift;
     my $text = shift or croak "need text to light()";
 
@@ -246,29 +202,25 @@ sub html
     # if the query text matched in the text, then we need to
     # use our prebuilt regexp
 
-  Q: for my $query ($self->_kworder)
-    {
-        my $re   = $self->rekw->re($query)->html;
-        my $real = $self->_get_real_html(\$text, $re);
+Q: for my $query ( $self->_kworder ) {
+        my $re = $self->rekw->re($query)->html;
+        my $real = $self->_get_real_html( \$text, $re );
 
-      R: for my $r (keys %$real)
-        {
-            push(@{$q2real->{$query}}, $r) while $real->{$r}--;
+    R: for my $r ( keys %$real ) {
+            push( @{ $q2real->{$query} }, $r ) while $real->{$r}--;
         }
     }
 
     ## 2
 
-  HILITE: for my $q ($self->_kworder)
-    {
+HILITE: for my $q ( $self->_kworder ) {
 
         my %uniq_reals = ();
-        $uniq_reals{$_}++ for @{$q2real->{$q}};
+        $uniq_reals{$_}++ for @{ $q2real->{$q} };
 
-      REAL: for my $real (keys %uniq_reals)
-        {
+    REAL: for my $real ( keys %uniq_reals ) {
 
-            $self->_add_hilite_tags(\$text, $q, $real);
+            $self->_add_hilite_tags( \$text, $q, $real );
 
         }
 
@@ -277,8 +229,7 @@ sub html
     return $text;
 }
 
-sub _add_hilite_tags
-{
+sub _add_hilite_tags {
     my $self  = shift;
     my $text  = shift;    # reference
     my $query = shift;
@@ -299,108 +250,102 @@ sub _add_hilite_tags
     # pre-fix nested tags in match
     my $pre_fixed = $html;
     my $pre_added = $pre_fixed =~ s($Search::Tools::RegExp::TagRE+)$c$1$og;
-    my $len_added = length($c . $o) * $pre_added;
+    my $len_added = length( $c . $o ) * $pre_added;
 
     # should be same as length( $to_hilite) - length( $prefixed );
-    my $len_diff = (length($html) - length($pre_fixed));
+    my $len_diff = ( length($html) - length($pre_fixed) );
     $len_diff *= -1
-      if $len_diff < 0;    # pre_added might be -1 if no subs were made
-    if ($len_diff != $len_added)
-    {
+        if $len_diff < 0;    # pre_added might be -1 if no subs were made
+    if ( $len_diff != $len_added ) {
         carp "length math failed!"
-          . "len_diff = $len_diff\nlen_added = $len_added";
+            . "len_diff = $len_diff\nlen_added = $len_added";
     }
 
-    while ($$text =~ m/($st_bound)($safe)($end_bound)/g)
-    {
+    while ( $$text =~ m/($st_bound)($safe)($end_bound)/g ) {
         my $s = $1;
         my $m = $2;
         my $e = $3;
-        if ($self->debug > 1)
-        {
+        if ( $self->debug > 1 ) {
 
             #print "$OC add_hilite_tags:\n$st_bound\n$safe\n$end_bound\n $CC";
             carp "matched:\n'$s'\n'$m'\n'$e'\n"
-              . "\$1 is "
-              . ord($s)
-              . "\$3 is "
-              . ord($e);
+                . "\$1 is "
+                . ord($s)
+                . "\$3 is "
+                . ord($e);
         }
 
         # use substr to do what s// would normally do if pos() wasn't an issue
         # -- is this a big speed hit?
-        my $len       = length($s . $m . $e);
+        my $len       = length( $s . $m . $e );
         my $pos       = pos($$text);
         my $newstring = $s . $o . $pre_fixed . $c . $e;
-        substr($$text, $pos - $len, $len, $newstring);
+        substr( $$text, $pos - $len, $len, $newstring );
 
-        pos($$text) = $pos + length($o . $c) + $len_added - 1;
+        pos($$text) = $pos + length( $o . $c ) + $len_added - 1;
 
-        # adjust for new text added
-        # $pre_fixed is the hard bit, since we must take $len_added into account
-        # move back 1 to reconsider $3 as next $1
+      # adjust for new text added
+      # $pre_fixed is the hard bit, since we must take $len_added into account
+      # move back 1 to reconsider $3 as next $1
 
-        #		warn "pos was $pos\nnow ", pos( $html ), "\n";
-        #		warn "new: '$html'\n";
-        #		warn "new text: '$newstring'\n";
-        #		warn "first chars of new pos are '", substr( $html, pos($html), 10 ), "'\n";
+#		warn "pos was $pos\nnow ", pos( $html ), "\n";
+#		warn "new: '$html'\n";
+#		warn "new text: '$newstring'\n";
+#		warn "first chars of new pos are '", substr( $html, pos($html), 10 ), "'\n";
 
     }
 
-    $self->_clean_up_hilites($text, $query, $o, $c, $safe);
+    $self->_clean_up_hilites( $text, $query, $o, $c, $safe );
 
 }
 
 # no algorithm is perfect. fix it as best we can.
-sub _clean_up_hilites
-{
+sub _clean_up_hilites {
 
     my $self = shift;
-    my ($text, $query, $o, $c, $safe) = @_;
+    my ( $text, $query, $o, $c, $safe ) = @_;
 
     # empty hilites are useless
-    my $empty = ($$text =~ s,\Q$o$c\E,,sgi) || 0;
+    my $empty = ( $$text =~ s,\Q$o$c\E,,sgi ) || 0;
 
-    #$self->debug and carp "looking for split entities: (&[\\w#]*)\Q$o\E(?:\Q$c\E)(${safe})\Q$c\E([\\w#]*;)";
+#$self->debug and carp "looking for split entities: (&[\\w#]*)\Q$o\E(?:\Q$c\E)(${safe})\Q$c\E([\\w#]*;)";
 
-    # to be safe: in some cases we might match against entities or within tag content.
+# to be safe: in some cases we might match against entities or within tag content.
     my $ent_split = (
-        $$text =~
-          s/(&[\w#]*)\Q$o\E(?:\Q$c\E)?(${safe})\Q$c\E([\w#]*;)/$1$2$3/igs # is i and s necessary?
-      )
-      || 0;
+        $$text
+            =~ s/(&[\w#]*)\Q$o\E(?:\Q$c\E)?(${safe})\Q$c\E([\w#]*;)/$1$2$3/igs # is i and s necessary?
+    ) || 0;
 
     #$self->debug and carp "found $ent_split split entities";
 
     my $tag_split = 0;
     while (
-        $$text =~
-        m/(<[^<>]*)\Q$o\E($safe)\Q$c\E([^>]*>)/gxsi # are these xsi flags necessary?
-          )
+        $$text
+        =~ m/(<[^<>]*)\Q$o\E($safe)\Q$c\E([^>]*>)/gxsi # are these xsi flags necessary?
+        )
     {
 
-        my $first = $1;
+        my $first  = $1;
         my $second = $2;
-        my $third = $3;
-        carp "appears to split tag: $first - $second - $third" if $self->debug > 1;
-        
-        # TODO this would be one place to highlight text where attributes match
+        my $third  = $3;
+        carp "appears to split tag: $first - $second - $third"
+            if $self->debug > 1;
 
-        $tag_split +=
-          ($$text =~ s/(<[^<>]*)\Q$o\E($safe)\Q$c\E([^>]*>)/$1$2$3/gxsi);
+       # TODO this would be one place to highlight text where attributes match
+
+        $tag_split += (
+            $$text =~ s/(<[^<>]*)\Q$o\E($safe)\Q$c\E([^>]*>)/$1$2$3/gxsi );
 
     }
 
 }
 
 # based on HTML::HiLiter plaintext()
-sub plain
-{
+sub plain {
     my $self = shift;
     my $text = shift or croak "need text to light()";
 
-  Q: for my $query ($self->_kworder)
-    {
+Q: for my $query ( $self->_kworder ) {
         my $re = $self->rekw->re($query)->plain;
         my $o  = $self->open_tag($query);
         my $c  = $self->close_tag($query);
@@ -413,8 +358,7 @@ sub plain
         # this can suck into an infinite loop because increm pos()-- results
         # in repeated match on nonwordchar: > (since we just added a tag)
 
-        while ($text =~ m/$re/g)
-        {
+        while ( $text =~ m/$re/g ) {
 
             my $s = $1 || '';
             my $m = $2 || $query;
@@ -422,17 +366,17 @@ sub plain
 
             $self->debug > 1 and carp "matched $s $m $e against $re";
 
-            # use substr to do what s// would normally do if pos() wasn't an issue
-            # -- is this a big speed diff?
-            my $len       = length($s . $m . $e);
+        # use substr to do what s// would normally do if pos() wasn't an issue
+        # -- is this a big speed diff?
+            my $len       = length( $s . $m . $e );
             my $pos       = pos($text);
             my $newstring = $s . $o . $m . $c . $e;
-            substr($text, $pos - $len, $len, $newstring);
+            substr( $text, $pos - $len, $len, $newstring );
 
             last if $pos == length $text;
 
-            # need to account for all the new chars we just added with length(...)
-            pos($text) = $pos + length($o . $c) - 1;
+        # need to account for all the new chars we just added with length(...)
+            pos($text) = $pos + length( $o . $c ) - 1;
 
         }
 
