@@ -10,52 +10,37 @@ use strict;
 use warnings;
 
 use Carp;
-
-#use Data::Dumper;      # just for debugging
 use Search::Tools::XML;
 use Search::Tools::RegExp;
 
-use base qw( Class::Accessor::Fast );
+use base qw( Search::Tools::Object );
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 our $ellip   = ' ... ';
 
-sub new
-{
-    my $class = shift;
-    my $self  = {};
-    bless($self, $class);
-    $self->_init(@_);
-    return $self;
-}
+__PACKAGE__->mk_accessors(
+    qw(
+        query
+        rekw
+        occur
+        context
+        max_chars
+        word_len
+        show
+        escape
+        snipper
+        snipper_name
+        snipper_force
+        snipper_type
+        count
+        collapse_whitespace
+        ),
+    @Search::Tools::Accessors
+);
 
-sub _init
-{
-    my $self  = shift;
-    my %extra = @_;
-    @$self{keys %extra} = values %extra;
-
-    $self->mk_accessors(
-        qw(
-          query
-          rekw
-          occur
-          context
-          max_chars
-          word_len
-          show
-          escape
-          snipper
-          snipper_name
-          snipper_force
-          snipper_type
-          count
-          collapse_whitespace
-          ),
-          @Search::Tools::Accessors
-    );
-    
-    $self->{debug} ||= $ENV{PERL_DEBUG} || 0;
+sub _init {
+    my $self = shift;
+    $self->SUPER::_init(@_);
 
     $self->{snipper_type} ||= 'loop';
     $self->{occur}        ||= 5;
@@ -63,32 +48,26 @@ sub _init
     $self->{context}      ||= 8;
     $self->{word_len}     ||= 5;
     $self->{show}         ||= 1;
-    for (qw/collapse_whitespace/)
-    {
+    for (qw/collapse_whitespace/) {
         $self->{$_} = 1 unless defined $self->{$_};
     }
 
-    if (!$self->query)
-    {
+    if ( !$self->query ) {
         croak "query required.";
     }
-    elsif (ref $self->query eq 'ARRAY' or !ref $self->query)
-    {
+    elsif ( ref $self->query eq 'ARRAY' or !ref $self->query ) {
         my $re = Search::Tools::RegExp->new;
-        $self->rekw($re->build($self->query));
+        $self->rekw( $re->build( $self->query ) );
     }
-    elsif ($self->query->isa('Search::Tools::RegExp::Keywords'))
-    {
-        $self->rekw($self->query);
+    elsif ( $self->query->isa('Search::Tools::RegExp::Keywords') ) {
+        $self->rekw( $self->query );
     }
-    else
-    {
+    else {
         croak
-          "query must be either a string or Search::Tools::RegExp::Keywords object";
+            "query must be either a string or Search::Tools::RegExp::Keywords object";
     }
 
-    unless ($self->rekw)
-    {
+    unless ( $self->rekw ) {
         croak "Search:Tools::RegExp::Keywords object required";
     }
 
@@ -97,38 +76,33 @@ sub _init
 
     # default snipper is loop_snip since it is fastest for single words
     # but we can specify re_snip if we want
-    if ($self->snipper_type eq 're')
-    {
-        $self->snipper(\&_re_snip);
+    if ( $self->snipper_type eq 're' ) {
+        $self->snipper( \&_re_snip );
     }
-    else
-    {
-        $self->snipper(\&_loop_snip) unless $self->snipper;
+    else {
+        $self->snipper( \&_loop_snip ) unless $self->snipper;
     }
 
     $self->count(0);
 
 }
 
-sub _word_regexp
-{
+sub _word_regexp {
 
     # this based on SWISH::PhraseHighlight::set_match_regexp()
 
     my $self = shift;
     my $wc   = $self->rekw->word_characters;
-    $self->{_wc_regexp} = qr/[^$wc]+/io; # regexp for splitting into swish-words
+    $self->{_wc_regexp}
+        = qr/[^$wc]+/io;    # regexp for splitting into swish-words
 
     my $igf = $self->rekw->ignore_first_char;
     my $igl = $self->rekw->ignore_last_char;
-    for ($igf, $igl)
-    {
-        if ($_)
-        {
+    for ( $igf, $igl ) {
+        if ($_) {
             $_ = "[$_]*";
         }
-        else
-        {
+        else {
             $_ = '';
         }
     }
@@ -137,8 +111,7 @@ sub _word_regexp
     $self->{_ignoreLast}  = $igl;
 }
 
-sub _build_query
-{
+sub _build_query {
     my $self     = shift;
     my $wildcard = $self->rekw->wildcard || '*';
     my $wild_esc = quotemeta($wildcard);
@@ -148,26 +121,25 @@ sub _build_query
     my @re;
     my $wc = $self->rekw->word_characters;
 
-    for ($self->rekw->keywords)
-    {
+    for ( $self->rekw->keywords ) {
 
         my $q = quotemeta($_);    # quotemeta speeds up the match, too
                                   # even though we have to unquote below
 
         $q =~ s/\\$wild_esc/[$wc]*/;    # wildcard match is very approximate
 
-        push(@re, $q);
+        push( @re, $q );
 
         my $r = {
-                 safe  => $q,
-                 plain => $self->rekw->re($_)->plain,
-                 html  => $self->rekw->re($_)->html
-                };
+            safe  => $q,
+            plain => $self->rekw->re($_)->plain,
+            html  => $self->rekw->re($_)->html
+        };
 
         $self->{_re}->{$_} = $r;
 
     }
-    my $j = join('|', @re);
+    my $j = join( '|', @re );
     $self->{_qre} = qr/($self->{_ignoreFirst}$j$self->{_ignoreLast})/i;
 
 }
@@ -177,8 +149,7 @@ sub _build_query
 # I have found that loop_snip() is faster for single-word queries,
 # while re_snip() seems to be the best compromise between speed and accuracy
 
-sub snip
-{
+sub snip {
     my $self = shift;
     my $text = shift or return '';
     my $func = $self->snipper;
@@ -187,23 +158,21 @@ sub snip
 
     # phrases must use re_snip()
     # so check if any of our queries contain a space
-    if (grep { /\ / } $self->rekw->keywords)
-    {
+    if ( grep {/\ /} $self->rekw->keywords ) {
         $func = \&_re_snip unless $self->snipper_force;
     }
 
     # don't snip if we're less than the threshold
     return $text if length($text) < $self->max_chars;
 
-    my $s = &$func($self, $text);
+    my $s = &$func( $self, $text );
 
     #carp "snipped: $s";
 
     # sanity check
-    $s = $self->_dumb_snip($s) if (length($s) > ($self->max_chars * 2));
+    $s = $self->_dumb_snip($s) if ( length($s) > ( $self->max_chars * 2 ) );
 
-    if ($self->collapse_whitespace)
-    {
+    if ( $self->collapse_whitespace ) {
         $s =~ s,[\s\xa0]+,\ ,g;
     }
 
@@ -211,8 +180,7 @@ sub snip
 
 }
 
-sub _loop_snip
-{
+sub _loop_snip {
 
     my $self = shift;
     $self->snipper_name('loop_snip');
@@ -236,13 +204,12 @@ sub _loop_snip
 
     my $notwc = $self->{_wc_regexp};
 
-    my @words       = split(/($notwc)/, $txt);
+    my @words       = split( /($notwc)/, $txt );
     my $count       = -1;
     my $start_again = $count;
     my $total       = 0;
 
-  WORD: for my $w (@words)
-    {
+WORD: for my $w (@words) {
 
         #print ">>\n" if $count % 2;
         #print "word: '$w'\n";
@@ -256,8 +223,7 @@ sub _loop_snip
         my $next = $count + 1;
 
         #warn '-' x 30 . "\n";
-        if ($w =~ m/^$regexp$/)
-        {
+        if ( $w =~ m/^$regexp$/ ) {
 
             #print "w: '$w' match: '$1'\n";
 
@@ -268,13 +234,13 @@ sub _loop_snip
 
             #warn "$before .. $last, $count, $next .. $after\n";
 
-            my @before = @words[$before .. $last];
-            my @after  = @words[$next .. $after];
+            my @before = @words[ $before .. $last ];
+            my @after  = @words[ $next .. $after ];
 
-            $total += grep { m/^$regexp$/i } (@before, @after);
+            $total += grep {m/^$regexp$/i} ( @before, @after );
             $total++;    # for current $w
 
-            my $t = join('', @before, $w, @after);
+            my $t = join( '', @before, $w, @after );
 
             $t .= $ellip unless $count == $#words;
 
@@ -284,7 +250,7 @@ sub _loop_snip
 
             #warn "total: $total\n";
 
-            push(@snips, $t);
+            push( @snips, $t );
             last WORD if scalar @snips >= $occur;
 
             $start_again = $after;
@@ -301,9 +267,9 @@ sub _loop_snip
 
     #warn '-' x 50 . "\n";
 
-    $self->count(scalar(@snips) + $self->count);
+    $self->count( scalar(@snips) + $self->count );
 
-    my $snippet = join('', @snips);
+    my $snippet = join( '', @snips );
     $snippet = $ellip . $snippet unless $snippet =~ m/^$words[0]/;
 
     $self->_escape($snippet);
@@ -312,10 +278,9 @@ sub _loop_snip
 
 }
 
-sub _re_snip
-{
+sub _re_snip {
 
-    # get first N matches for each q, then take one of each till we have $occur
+   # get first N matches for each q, then take one of each till we have $occur
 
     my $self = shift;
     my $text = shift;
@@ -328,42 +293,38 @@ sub _re_snip
     my $notwc = $self->{_wc_regexp};
 
     # get minimum number of snips necessary to meet $occur
-    my $snip_per_q = int($occur / scalar(@q)) + 1;
+    my $snip_per_q = int( $occur / scalar(@q) ) + 1;
 
-    my (%snips, @snips, %ranges);
+    my ( %snips, @snips, %ranges );
 
-  Q: for my $q (@q)
-    {
-        $snips{$q} = {t => [], offset => []};
+Q: for my $q (@q) {
+        $snips{$q} = { t => [], offset => [] };
 
         # try simple regexp first, then more complex if we don't match
         next Q
-          if $self->_re_match(\$text, $self->{_re}->{$q}->{plain},
-                              \$total, $snips{$q}, \%ranges, $Nchar,
-                              $snip_per_q);
+            if $self->_re_match( \$text, $self->{_re}->{$q}->{plain},
+            \$total, $snips{$q}, \%ranges, $Nchar, $snip_per_q );
 
         pos $text = 0;    # do we really need to reset this?
 
-        $self->_re_match(\$text, $self->{_re}->{$q}->{html},
-                         \$total, $snips{$q}, \%ranges, $Nchar, $snip_per_q);
+        $self->_re_match( \$text, $self->{_re}->{$q}->{html},
+            \$total, $snips{$q}, \%ranges, $Nchar, $snip_per_q );
 
     }
 
     return $self->_dumb_snip($text) unless $total;
 
-    # get all snips into one array in order they appeared in $text
-    # should be a max of $snip_per_q in any one $q snip array
-    # so we should have at least $occur in total, which we'll splice() if need be
+ # get all snips into one array in order they appeared in $text
+ # should be a max of $snip_per_q in any one $q snip array
+ # so we should have at least $occur in total, which we'll splice() if need be
 
     my %offsets;
-    for my $q (keys %snips)
-    {
-        my @s = @{$snips{$q}->{t}};
-        my @o = @{$snips{$q}->{offset}};
+    for my $q ( keys %snips ) {
+        my @s = @{ $snips{$q}->{t} };
+        my @o = @{ $snips{$q}->{offset} };
 
         my $i = 0;
-        for (@s)
-        {
+        for (@s) {
             $offsets{$_} = $o[$i];
         }
     }
@@ -375,9 +336,9 @@ sub _re_snip
     $snips[0] = $ellip . $snips[0] unless $text =~ m/^\Q$snips[0]/i;
     $snips[-1] .= $ellip unless $text =~ m/\Q$snips[-1]$/i;
 
-    my $snip = join($ellip, @snips);
+    my $snip = join( $ellip, @snips );
 
-    $self->count(scalar(@snips) + $self->count);
+    $self->count( scalar(@snips) + $self->count );
 
     $self->_escape($snip);
 
@@ -385,22 +346,21 @@ sub _re_snip
 
 }
 
-sub _re_match
-{
+sub _re_match {
 
-    # the .{0,$Nchar} regexp slows things WAY down. so just match, then use pos() to get
-    # chars before and after.
+# the .{0,$Nchar} regexp slows things WAY down. so just match, then use pos() to get
+# chars before and after.
 
-    # if escape = 0 and if prefix or suffix contains a < or >, try to include entire tagset.
+# if escape = 0 and if prefix or suffix contains a < or >, try to include entire tagset.
 
-    my ($self, $text, $re, $total, $snips, $ranges, $Nchar, $max_snips) = @_;
+    my ( $self, $text, $re, $total, $snips, $ranges, $Nchar, $max_snips )
+        = @_;
 
     my $t_len = length $$text;
 
     my $cnt = 0;
 
-  RE: while ($$text =~ m/$re/gi)
-    {
+RE: while ( $$text =~ m/$re/gi ) {
 
         #		warn "re: '$re'\n";
         #		warn "\$1 = '$1' = ", ord( $1 ), "\n";
@@ -419,13 +379,13 @@ sub _re_match
         my $start_match = $pos - $len - 1;    # -1 to offset $1
         $start_match = 0 if $start_match < 0;
 
-        # sanity
-        #warn "match should be: '", substr( $$text, $start_match, $len ), "'\n";
+      # sanity
+      #warn "match should be: '", substr( $$text, $start_match, $len ), "'\n";
 
-        my $prefix_start =
-          $start_match < $Nchar
-          ? 0
-          : $start_match - $Nchar;
+        my $prefix_start
+            = $start_match < $Nchar
+            ? 0
+            : $start_match - $Nchar;
 
         my $prefix_len = $start_match - $prefix_start;
 
@@ -437,7 +397,7 @@ sub _re_match
 
         # if $end extends beyond, that's ok, substr compensates
 
-        $ranges->{$_}++ for ($prefix_start .. $end);
+        $ranges->{$_}++ for ( $prefix_start .. $end );
 
         #		warn "prefix_start = $prefix_start\n";
         #		warn "prefix_len = $prefix_len\n";
@@ -449,8 +409,8 @@ sub _re_match
         #		warn "suffix_len = $suffix_len\n";
         #		warn "end = $end\n";
 
-        my $prefix = substr($$text, $prefix_start, $prefix_len);
-        my $suffix = substr($$text, $suffix_start, $suffix_len);
+        my $prefix = substr( $$text, $prefix_start, $prefix_len );
+        my $suffix = substr( $$text, $suffix_start, $suffix_len );
 
         #		warn "prefix: '$prefix'\n";
         #		warn "match:  '$match'\n";
@@ -459,15 +419,15 @@ sub _re_match
         # try and get whole words if we split one up
         # _no_*_partial does this more rudely
 
-        # might be faster to do m/(\S)*$prefix/i
-        # but we couldn't guarantee position accuracy
-        # e.g. if $prefix matched more than once in $$text, we might pull the wrong \S*
+# might be faster to do m/(\S)*$prefix/i
+# but we couldn't guarantee position accuracy
+# e.g. if $prefix matched more than once in $$text, we might pull the wrong \S*
 
-        unless ($prefix =~ m/^\s/
-                or substr($$text, $prefix_start - 1, 1) =~ m/(\s)/)
+        unless ( $prefix =~ m/^\s/
+            or substr( $$text, $prefix_start - 1, 1 ) =~ m/(\s)/ )
         {
-            while (--$prefix_start >= 0
-                   and substr($$text, $prefix_start, 1) =~ m/(\S)/)
+            while ( --$prefix_start >= 0
+                and substr( $$text, $prefix_start, 1 ) =~ m/(\S)/ )
             {
                 my $onemorechar = $1;
 
@@ -483,9 +443,9 @@ sub _re_match
         # We get error here under -w
         # about substr outside of string -- is $end undefined sometimes??
 
-        unless ($suffix =~ m/\s$/ or substr($$text, $end, 1) =~ m/(\s)/)
-        {
-            while ($end <= $t_len and substr($$text, $end++, 1) =~ m/(\S)/)
+        unless ( $suffix =~ m/\s$/ or substr( $$text, $end, 1 ) =~ m/(\s)/ ) {
+            while ( $end <= $t_len
+                and substr( $$text, $end++, 1 ) =~ m/(\S)/ )
             {
 
                 my $onemore = $1;
@@ -499,21 +459,19 @@ sub _re_match
         }
 
         # will likely fail to include one half of tagset if other is complete
-        unless ($self->escape)
-        {
+        unless ( $self->escape ) {
             my $sanity = 0;
-            my @l      = ($prefix =~ /(<)/g);
-            my @r      = ($prefix =~ /(>)/g);
-            while (scalar @l != scalar @r)
-            {
+            my @l      = ( $prefix =~ /(<)/g );
+            my @r      = ( $prefix =~ /(>)/g );
+            while ( scalar @l != scalar @r ) {
 
-                @l = ($prefix =~ /(<)/g);
-                @r = ($prefix =~ /(>)/g);
+                @l = ( $prefix =~ /(<)/g );
+                @r = ( $prefix =~ /(>)/g );
                 last
-                  if scalar @l ==
-                  scalar @r;    # don't take any more than we need to
+                    if scalar @l
+                        == scalar @r;    # don't take any more than we need to
 
-                my $onemorechar = substr($$text, $prefix_start--, 1);
+                my $onemorechar = substr( $$text, $prefix_start--, 1 );
 
                 #warn "tagfix: adding $onemorechar to prefix\n";
                 $prefix = $onemorechar . $prefix;
@@ -523,10 +481,9 @@ sub _re_match
             }
 
             $sanity = 0;
-            while ($suffix =~ /<(\w+)/ && $suffix !~ /<\/$1>/)
-            {
+            while ( $suffix =~ /<(\w+)/ && $suffix !~ /<\/$1>/ ) {
 
-                my $onemorechar = substr($$text, $end, 1);
+                my $onemorechar = substr( $$text, $end, 1 );
 
                 #warn "tagfix: adding $onemorechar to suffix\n";
                 $suffix .= $onemorechar;
@@ -540,12 +497,12 @@ sub _re_match
         #		warn "match:  '$match'\n";
         #		warn "suffix: '$suffix'\n";
 
-        my $context = join('', $prefix, $match, $suffix);
+        my $context = join( '', $prefix, $match, $suffix );
 
         #warn "context is '$context'\n";
 
-        push(@{$snips->{t}},      $context);
-        push(@{$snips->{offset}}, $prefix_start);
+        push( @{ $snips->{t} },      $context );
+        push( @{ $snips->{offset} }, $prefix_start );
 
         $$total++;
 
@@ -557,8 +514,7 @@ sub _re_match
     return $cnt;
 }
 
-sub _dumb_snip
-{
+sub _dumb_snip {
 
     # just grap the first X chars and return
 
@@ -569,33 +525,29 @@ sub _dumb_snip
     my $max = $self->max_chars;
     $self->snipper_name('dumb_snip');
 
-    my $show = substr($txt, 0, $max);
+    my $show = substr( $txt, 0, $max );
     $self->_no_end_partial($show);
     $show .= $ellip;
     $self->_escape($show);
 
-    $self->count(1 + $self->count);
+    $self->count( 1 + $self->count );
 
     return $show;
 
 }
 
-sub _no_start_partial
-{
+sub _no_start_partial {
     $_[0] =~ s/^\S+\s+//gs;
 }
 
-sub _no_end_partial
-{
+sub _no_end_partial {
     $_[0] =~ s/\s+\S+$//gs;
 }
 
-sub _escape
-{
+sub _escape {
     my $self = shift;
-    if ($self->escape)
-    {
-        Search::Tools::XML->escape($_[0]);
+    if ( $self->escape ) {
+        return Search::Tools::XML->escape( $_[0] );
     }
 }
 
